==> dbix-0.1.2.tar.gz: dbix-0.1.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    # TODO: put package requirements here
]

setup_requirements = [
    'pytest-runner',
    # TODO(alexbodn): put setup requirements (distutils extensions, etc.) here
]

test_requirements = [
    'pytest',
    'MySQL-python',
    'psycopg2',
    # TODO: put package test requirements here
]

setup(
    name='dbix',
    version='0.1.2',
    description="load a perl DBIx::Class schema with python",
    long_description=readme + '\n\n' + history,
    author="Alex Bodnaru",
    author_email='alexbodn@gmail.com',
    url='https://github.com/alexbodn/dbix',
    packages=find_packages(include=['dbix']),
    entry_points={
        'console_scripts': [
            'dbix=dbix.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache Software License 2.0",
    zip_safe=False,
    keywords='dbix',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)

==> dbix-0.1.4.tar.gz: dbix-0.1.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'future',
]

setup_requirements = [
    'pytest-runner',
]

test_requirements = [
    'pytest',
]

setup(
    name='dbix',
    version='0.1.4',
    description="load a perl DBIx::Class schema with python",
    long_description=readme + '\n\n' + history,
    author="Alex Bodnaru",
    author_email='alexbodn@gmail.com',
    url='https://github.com/alexbodn/python-dbix',
    packages=find_packages(include=['dbix']),
    entry_points={
        'console_scripts': [
            'dbix=dbix.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache Software License 2.0",
    zip_safe=False,
    keywords='dbix',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)
